# Copyright 1995, Peter S. Shenkin, all rights reserved.
# Permission is granted to utilize and disseminate this code or
#  document without charge, provided that (1) this copyright notice is 
#  not removed, and (2) all changes made by other than members of the 
#  MacroModel Development Group at Columbia University are, if further 
#  disseminated, (a) noted as such; for example, by means of source-code 
#  comment lines, and (b) communicated back to the author for possible 
#  inclusion in subsequent versions.

#################################################################
# *** $RCSfile: Makefile.pro,v $
# *** $Revision: 1.47 $
# *** $Date: 1998/04/03 22:21:46 $
#################################################################

####### USING THIS MAKEFILE: ########

# Makefile.pro contains code to make Makefiles for a variety of machines.

# For simple makes from the current directory, in a MacroModel
#  distribution, the next block should be uncommented and the 
#  following block commented out:
#MMIO_SRC_DIR = .
#MMOD_ROOT = ../../..
#MASTER_MMOD_ROOT = ../../..
#BUILD_TOOLS = $(MASTER_MMOD_ROOT)/src/build_tools

# For a local make where the source code is taken from a remote directory,
#  MASTER_MMOD_ROOT (parent mmod directory of the source) and MMOD_ROOT 
#  (parent mmod directory on the local machine) must be defined in the
#  environment.  The previous block should be commented out and the
#  following block should be uncommented; this also assumes that
#  a full MacroModel execution or source tree is installed:
MMIO_SRC_DIR = $(MASTER_MMOD_ROOT)/develop/src/mmio
BUILD_TOOLS = $(MASTER_MMOD_ROOT)/src/build_tools

# For standalone makes of MMIO, when MacroModel is not installed
#  (as for a third-party user of MMIO), the following block should
#  be uncommented;  ordinarily, MMIO will be supplied this way.
MMIO_SRC_DIR = .
MMOD_ROOT = .
MASTER_MMOD_ROOT = .
BUILD_TOOLS = .

# Then carry out the following procedure:
#	cp Makefile.pro Makefile # (only if there's no Makefile present)
#	make makefile VERSION=SGI-g # (SGI-g comes from the following list)
#	make version		 # (sanity check; should say "SGI-g")
#	make clean		 # (in case .o files were compiled otherwise)
#	make			 # (makes libraries, docs and sample programs)
#  This will overwrite the Makefile, but not Makefile.pro.

# Versions available:
#       DEC-g           DECstation Ultrix, debugging version
#       DEC-O           DECstation Ultrix, optimized version
#       IBM-g           IBM RISC AIX, debugging version
#       IBM-O           IBM RISC AIX, optimized version
#       IBM-O-pwr2      IBM RISC AIX, optimized for POWER2 architecture
#       IBM-O-ppc       IBM Power PC
#       SGI-g-mips2     SGI IRIX, -mips2 debugging version
#       SGI-O-mips2     SGI IRIX, -mips2 optimized version
#       SGI-g-mips3     SGI IRIX, -mips3 debugging version
#       SGI-O-mips3     SGI IRIX, -mips3 ptimized version
#       SGI-g-mips4     SGI IRIX, debugging version for R8000 processor
#       SGI-O-mips4     SGI IRIX, optimized version for R8000 processor
#       HP-g            HP HPUX, debugging version
#       HP-O            HP HPUX, optimized version
#       CONVEX-g        Convex with debugging
#       CONVEX-O        Convex with optimization
#       OSF-g           OSF (DEC Alpha) with debugging
#       OSF-O           OSF (DEC Alpha) with superoptimization
#       FUJITSU-g:      Fujitsu with debugging
#       FUJITSU-O:      Fujitsu with optimization
#       FUJITSU-VP-O    Fujitsu with optimization and auto vectorization
#	CRAY-YMP-O:	Cray YMP with optimization
#	CRAY-C90-O: 	Cray C90 with optimization
#	CRAY-C90-g: 	Cray C90 with debug
#################################################################

####### Usual definitions;  may be overridden in some branches: ########
LIB_DIR = $(MMOD_ROOT)/develop/lib
INC_DIR = $(MMOD_ROOT)/develop/include
EXEC_DIR = $(MMOD_ROOT)/run/exec
MMIO_OBJ = mmio.o mmioc.o mmiof-CF.o fout.o
MMIOC_OBJ = mmio-C.o mmioc.o
MMIOF_OBJ = mmio.o mmiof-F.o fout.o
CC = cc
ARFLAGS = rs

####### Machine dependencies: ########

#### SGI-g-mips2: SGI -mips2 with debugging
#SGI-g-mips2: F = f
#SGI-g-mips2: O = o
#SGI-g-mips2: FC   =  f77
#SGI-g-mips2: CFLAGS  = -c -mips2 -g -DBIND_ -DGETOPT_GETOPT
#SGI-g-mips2: FFLAGS = -c -mips2 -Nn10000 -Olimit 2500 -g -static -C #-trapuv
#SGI-g-mips2: LFLAGS = -32
#SGI-g-mips2: LIBS =
#SGI-g-mips2: VERSION = SGI-g-mips2

#### SGI-O-mips2: SGI with -O2 optimization and -mips2
#SGI-O-mips2: F = f
#SGI-O-mips2: O = o
#SGI-O-mips2: FC   =  f77
#SGI-O-mips2: CFLAGS  = -c -O2 -mips2 -Olimit 2500 -DBIND_ -DGETOPT_GETOPT
#SGI-O-mips2: FFLAGS  = -c -Nn10000 -Olimit 2500 -mips2 -static -O2 # -trapuv 
#SGI-O-mips2: LFLAGS = -32
#SGI-O-mips2: LIBS =
#SGI-O-mips2: VERSION = SGI-O-mips2

#### SGI-g-mips3: SGI with debugging for R4x00
#SGI-g-mips3: LIB_DIR = $(MMOD_ROOT)/develop/lib32
#SGI-g-mips3: F = f
#SGI-g-mips3: O = o
#SGI-g-mips3: FC   =  f77
#SGI-g-mips3: CFLAGS  = -c -g -mips3 -DBIND_ -DGETOPT_GETOPT -n32 \
#SGI-g-mips3:  -TARG:processor=r4000  
#SGI-g-mips3: FFLAGS = -c -g -C -mips3 -n32 
#SGI-g-mips3: FOPT = $(FFLAGS) 
#SGI-g-mips3: LFLAGS =  -n32
#SGI-g-mips3: LIBS =
#SGI-g-mips3: VERSION = SGI-g-mips3

#### SGI-O-mips3: SGI with -O3 optimization and -mips3 for R4x00
#SGI-O-mips3: LIB_DIR = $(MMOD_ROOT)/develop/lib32
#SGI-O-mips3: F = f
#SGI-O-mips3: O = o
#SGI-O-mips3: FC   =  f77
#SGI-O-mips3: CFLAGS  = -c -mips3 -DBIND_ -DGETOPT_GETOPT -n32 \
#SGI-O-mips3:  -TARG:processor=r4000 -O3
#SGI-O-mips3: FFLAGS = -c  -C -mips3 -n32 \
#SGI-O-mips3:  -TARG:processor=r4000 
#SGI-O-mips3: FOPT = $(FFLAGS) -O3 
#SGI-O-mips3: LFLAGS =  -n32
#SGI-O-mips3: LIBS =
#SGI-O-mips3: VERSION = SGI-O-mips3

#### SGI-g-mips4: SGI with debugging for R8000
#SGI-g-mips4: LIB_DIR = $(MMOD_ROOT)/develop/lib32
#SGI-g-mips4: F = f
#SGI-g-mips4: O = o
#SGI-g-mips4: FC   =  f77
#SGI-g-mips4: CFLAGS  = -c -g -mips4 -DBIND_ -DGETOPT_GETOPT -n32 \
#SGI-g-mips4:  -TARG:processor=r10000 -r10000 
#SGI-g-mips4: FFLAGS = -c -g -C -mips4 -n32 #-trapuv
#SGI-g-mips4: LFLAGS =   -n32
#SGI-g-mips4: LIBS =
#SGI-g-mips4: VERSION = SGI-g-mips4

#### SGI-O-mips4: SGI with -O3 optimization and -mips4
#SGI-O-mips4: LIB_DIR = $(MMOD_ROOT)/develop/lib32
#SGI-O-mips4: F = f
#SGI-O-mips4: O = o
#SGI-O-mips4: FC   =  f77
# N.B.:  in 7.0 compilers, -O3 compiler bug causes failure of in write_ct():
#  loop zeroing out bond atoms and params from nbond through MAX_BOND is
#  skipped.  So -O2 (which works) is used.
#SGI-O-mips4: CFLAGS  = -c -mips4 -n32 -O2 \
#SGI-O-mips4:  -OPT:roundoff=3:IEEE_arithmetic=3 \
#SGI-O-mips4:  -WK,-o=0,-so=0,-ndr -TARG:processor=r10000 -r10000 \
#SGI-O-mips4:  -TENV:X=1 -DBIND_ -DGETOPT_GETOPT \
#SGI-O-mips4:  -TARG:processor=r10000 -r10000 -O3
#SGI-O-mips4: FFLAGS  = -c -mips4 -n32 -O3 \
#SGI-O-mips4:  -OPT:roundoff=3:IEEE_arithmetic=3 \
#SGI-O-mips4:  -WK,-o=0,-so=0,-ndr -TARG:processor=r10000 -r10000 \
#SGI-O-mips4:  -TENV:X=1
#SGI-O-mips4: LFLAGS = -n32
#SGI-O-mips4: LIBS =
#SGI-O-mips4: VERSION = SGI-O-mips4

#### DEC-O: DEC ULTRIX with optimization
#DEC-O: F = f
#DEC-O: O = o
#DEC-O: FC   =  f77
#DEC-O: CFLAGS  = -c -O -DBIND_ -DGETOPT_STDLIB
#DEC-O: FFLAGS = -c -O
#DEC-O: LFLAGS =
#DEC-O: LIBS =
#DEC-O: VERSION = DEC-O

#### DEC-g: DEC ULTRIX with debugging
#DEC-g: F = f
#DEC-g: O = o
#DEC-g: FC   =  f77
#DEC-g: CFLAGS  = -c -g -DBIND_ -DGETOPT_STDLIB
#DEC-g: FFLAGS = -c -g
#DEC-g: LFLAGS =
#DEC-g: LIBS =
#DEC-g: VERSION = DEC-g

#### IBM-O: IBM RS6000 with optimization
#IBM-O: F = f
#IBM-O: O = o
#IBM-O: FC = xlf
#IBM-O: CFLAGS  = -c -O -DBIND -DGETOPT_UNISTD
#IBM-O: FFLAGS  = -c -O -qmaxmem=-1 -I. -qcharlen=32767 -qxlf77=leadzero
#IBM-O: LFLAGS =
#IBM-O: LIBS =
#IBM-O: VERSION = IBM-O

#### IBM-O-pwr2: IBM RS6000, optimized for pwr2 architecture
#IBM-O-pwr2: F = f
#IBM-O-pwr2: O = o
#IBM-O-pwr2: FC = xlf
#IBM-O-pwr2: CFLAGS  = -c -O -DBIND -qarch=pwr2 -DGETOPT_UNISTD
#IBM-O-pwr2: FFLAGS  = -c -NT40000 -NQ40000 -ND3100 -I. \
#IBM-O-pwr2:  -qcharlen=32767 -qarch=pwr2 -qxlf77=leadzero \
#IBM-O-pwr2:  -O -qmaxmem=-1 $(FFLAGS)
#IBM-O-pwr2: LFLAGS =
#IBM-O-pwr2: LIBS =
#IBM-O-pwr2: VERSION = IBM-O-pwr2

#### IBM-O-ppc: IBM ppc architecture
#IBM-O-ppc: F = f
#IBM-O-ppc: O = o
#IBM-O-ppc: FC = xlf
#IBM-O-ppc: CFLAGS  = -c -O -DBIND -qarch=ppc -DGETOPT_UNISTD
#IBM-O-ppc: FFLAGS  = -c -NT40000 -NQ40000 -ND3100 -I. \
#IBM-O-ppc:  -qcharlen=32767 -qarch=ppc -qxlf77=leadzero \
#IBM-O-ppc:  -O -qmaxmem=-1 $(FFLAGS)
#IBM-O-ppc: LFLAGS =
#IBM-O-ppc: LIBS =
#IBM-O-ppc: VERSION = IBM-O-ppc

#### IBM-g: IBM RS6000 with debugging
#IBM-g: F = f
#IBM-g: O = o
#IBM-g: FC = xlf
#IBM-g: CFLAGS  = -c -g -DBIND -DGETOPT_UNISTD
#IBM-g: FFLAGS  = -c -g -C -NT40000 -NQ40000 -ND3100 -I. -qcharlen=32767 -qxlf77=leadzero
#IBM-g: LFLAGS =
#IBM-g: LIBS =
#IBM-g: VERSION = IBM-g

#### HP-O: HP 9000/7xx with optimization:
#HP-O: F = f
#HP-O: O = o
#HP-O: FC   =  fort77
#HP-O: CFLAGS = -c -Aa -DBIND  -DHPUX -O -DGETOPT_UNISTD
#HP-O: FFLAGS = -c +E1 +O +U77 # +Qgetenv_c.alias
#HP-O: LFLAGS =
#HP-O: LIBS = +U77 
#HP-O: VERSION = HP-O

#### HP-g: HP 9000/7xx with debugging:
#HP-g: F = f
#HP-g: O = o
#HP-g: FC   =  fort77
#HP-g: CFLAGS  = -c -g -Aa -DBIND  -DHPUX -DGETOPT_UNISTD
#HP-g: FFLAGS  = -c -g +E1 +U77 # +Qgetenv_c.alias
#HP-g: LFLAGS =
#HP-g: LIBS = +U77
#HP-g: VERSION = HP-g

#### CONVEX-g: Convex with debugging
#CONVEX-g: FC   =  fc
#CONVEX-g: CFLAGS  = -c -g -DBIND_ -DCONVEX
#CONVEX-g: FFLAGS  = -c -g -cs
#CONVEX-g: LFLAGS =
#CONVEX-g: LIBS =
#CONVEX-g: VERSION = CONVEX-g
 
#### CONVEX-O: Convex with optimization
#CONVEX-O: FC   =  fc
#CONVEX-O: CFLAGS  = -c -O1 -DBIND_ -DCONVEX
#CONVEX-O: FFLAGS  = -c -O3
#CONVEX-O: LFLAGS =
#CONVEX-O: LIBS =
#CONVEX-O: VERSION = CONVEX-O

#### OSF-g: (DEC Alpha) with debugging
#OSF-g: FC   =  f77
#OSF-g: CFLAGS  = -c -g -std1 -DBIND_  
#OSF-g: FFLAGS  = -c -g -static -non_shared -align dcommons -align records
#OSF-g: LFLAGS =
#OSF-g: LIBS =
#OSF-g: VERSION = OSF-g

#### OSF-O: OSF (DEC Alpha) with superoptimization
#OSF-O: FC   =  f77
#OSF-O: CFLAGS  = -c -O2 -std1 -Olimit 5000 -DBIND_  
#OSF-O: FFLAGS  = -c -static -non_shared -align dcommons \
#OSF-O:  -align records -math_library fast  -O4 -Olimit 5000
#OSF-O: LFLAGS =
#OSF-O: LIBS =
#OSF-O: VERSION = OSF-O


#### FUJITSU-g:  Fujitsu with debugging
#FUJITSU-g: FC = frt
#FUJITSU-g: CFLAGS = -c -g -DBIND_ -DUXPM -DGETOPT_STDLIB
#FUJITSU-g: FFLAGS = -c -g -Si -Ab
#FUJITSU-g: LFLAGS = 
#FUJITSU-g: LIBS =
#FUJITSU-g: VERSION = FUJITSU-g

#### FUJITSU-O:  Fujitsu with optimization
#FUJITSU-O: FC = frt
#FUJITSU-O: CFLAGS = -c -DBIND_ -DUXPM -DGETOPT_STDLIB
#FUJITSU-O: FFLAGS = -c -Si -Ob -Ab
#FUJITSU-O: LFLAGS =
#FUJITSU-O: LIBS =
#FUJITSU-O: VERSION = FUJITSU-O

#### FUJITSU-VP-O: Fujitsu with optimization and auto vectorization
#FUJITSU-VP-O: FC = frt
#FUJITSU-VP-O: CFLAGS = -c -DBIND_ -DUXPM -DGETOPT_STDLIB
#FUJITSU-VP-O: FFLAGS = -c -Si -Ob -Ab
#FUJITSU-VP-O: LFLAGS = -J -lsamp
#FUJITSU-VP-O: LIBS =
#FUJITSU-VP-O: VERSION = FUJITSU-VP-O

#### Cray YMP with optimization
#CRAY-YMP-O: FC   =  cf77 # /choose/ymp/6.1/bin/cf77
#CRAY-YMP-O: CFLAGS  = -c -DBINDCRAY -DSTRINGCRAY
#CRAY-YMP-O: FFLAGS  = -c -Wf"-a static -dp -oaggress" -Zv -Wf"-oinline3"
#CRAY-YMP-O: LFLAGS =
#CRAY-YMP-O: LIBS = -L/choose/ymp/6.1/lib $(LIB_DBMIN) $(LIB_MMIO) $(LIB_BMFFC)
#CRAY-YMP-O: ARFLAGS = r
#CRAY-YMP-O: VERSION = CRAY-YMP-O

#### Cray C90 with optimization
#CRAY-C90-O: FC   =  cf77 #/choose/c90/7.C/bin/cf77
#CRAY-C90-O: CFLAGS  = -c -DBINDCRAY -DSTRINGCRAY -I/opt/ctl/craylibs/craylibs/include
#CRAY-C90-O: FFLAGS  = -c -Wf"-a static -dp -oaggress" -Zv -Wf"-oinline3"
#CRAY-C90-O: LFLAGS =
#CRAY-C90-O: LIBS = $(LIB_DBMIN) $(LIB_MMIO) $(LIB_BMFFC) -L/choose/c90/7.C/lib 
#CRAY-C90-O: ARFLAGS = r
#CRAY-C90-O: VERSION = CRAY-C90-O

#### Cray C90 with debug
#CRAY-C90-g: FC   =  cf77 #/choose/c90/7.C/bin/cf77
#CRAY-C90-g: CFLAGS  = -c -DBINDCRAY -DSTRINGCRAY  -I/opt/ctl/craylibs/craylibs/include
#CRAY-C90-g: FFLAGS  = -c -Wf"-a static -dp " -f
#CRAY-C90-g: LFLAGS =
#CRAY-C90-g: LIBS =  $(LIB_DBMIN) $(LIB_MMIO) $(LIB_BMFFC) -L/choose/c90/7.C/lib
#CRAY-C90-g: ARFLAGS = r
#CRAY-C90-g: VERSION = CRAY-C90-g


###########################################################################
SRC = Makefile.pro Makefile cmmio.c fmmio.f fout.f mmio.c \
 mmio.h mmio.inc mmio_convert.c mmio_def.h mmio_uncompress.f mmioc.c \
 mmioc.h mmiof.c cfmmio.c fcmmio.f Makefile.none
MISC = README.src README ctest ftest cftest fctest \
 description.C description.Fortran description.all \
 copyright.C copyright.Fortran title.C title.Fortran \
 gagcomp.dat gagfull.dat prepmake make.version
OTHER_DIST = RCS_version my_cp
###########################################################################
all: libmmioc.a libmmio.a libmmio.a \
 cmmio fmmio cfmmio fcmmio mmio_uncompress mmio_convert README.Fortran \
 README.C ftest ctest cftest fctest gagfull.dat gagcomp.dat

README.Fortran: title.Fortran description.all description.Fortran
	cat title.Fortran description.all description.Fortran > README.Fortran

README.C: title.C description.all description.C
	cat title.C description.all description.C > README.C

makefile:
	$(BUILD_TOOLS)/prepmake $(MMIO_SRC_DIR) $(VERSION)
	mv Makefile.tmp Makefile

version:
	@make -f $(BUILD_TOOLS)/make.version version VERSION=$(VERSION)

clean:
	 -rm *.o

clean_all: clean
	 -rm cmmio fmmio cfmmio fcmmio mmio_uncompress mmio_convert *.a

clean_src: clean_target
	-rm *.c *.f *.h *.inc $(MISC) $(OTHER_DIST) README.C README.Fortran

install:
	make $(LIB_DIR)/libmmio.a \
	 $(LIB_DIR)/libmmioc.a \
	 $(LIB_DIR)/libmmiof.a \
	 $(INC_DIR)/mmio.h \
	 $(INC_DIR)/mmio_def.h \
	 $(INC_DIR)/mmio.inc \
	 $(EXEC_DIR)/mmio_convert

###### ci, freeze and distr targets must be made from MMIO_SRC_DIR:
ci:
	ci -l RCS/*,v
freeze:
	-rcsfreeze
	/bin/rm RCS_version
	cp RCS/.rcsfreeze.log RCS_version
	cp RCS/.rcsfreeze.ver RCS_number
distr:
	-rm -f dist/*
	mv Makefile Makefile.hold
	mv Makefile.pro Makefile.pro.hold
	prepmake.distr < Makefile.pro.hold > Makefile.pro
	cp Makefile.none Makefile
	chmod +r *
	tar cf dist/mmio_`cat RCS_number`.tar $(SRC) $(MISC) $(OTHER_DIST)
	cp README dist/mmio_`cat RCS_number`.txt
	chmod o-r *
	compress dist/mmio*tar
	( cd dist; uuencode mmio*Z mmio*Z > mmio_`cat ../RCS_number`.uu )
	mv Makefile.pro.hold Makefile.pro
	mv Makefile.hold Makefile

$(LIB_DIR)/libmmio.a: libmmio.a
	cp libmmio.a $(LIB_DIR)
$(LIB_DIR)/libmmioc.a: libmmioc.a
	cp libmmioc.a $(LIB_DIR)
$(LIB_DIR)/libmmiof.a: libmmiof.a
	cp libmmiof.a $(LIB_DIR)
$(INC_DIR)/mmio.h: mmio.h
	cp mmio.h $(INC_DIR)
$(INC_DIR)/mmio_def.h: mmio_def.h
	cp mmio_def.h $(INC_DIR)
$(INC_DIR)/mmio.inc: mmio.inc
	cp mmio.inc $(INC_DIR)
$(EXEC_DIR)/mmio_convert: mmio_convert
	cp mmio_convert $(EXEC_DIR)

mmio_convert: mmio_convert.o libmmio.a
	$(FC) $(LFLAGS) -o mmio_convert mmio_convert.o -L. -lmmio $(LIBS)

mmio_uncompress: mmio_uncompress.o libmmiof.a
	$(FC) $(LFLAGS) -o mmio_uncompress mmio_uncompress.o -L. -lmmiof $(LIBS)

cfmmio: cfmmio.o libmmio.a
	$(FC) $(LFLAGS) -o cfmmio cfmmio.o -L. -lmmio $(LIBS)

cmmio: cmmio.o libmmioc.a
	$(CC) $(LFLAGS) -o cmmio cmmio.o -L. -lmmioc $(LIBS)

fcmmio: fcmmio.o libmmio.a
	$(FC) $(LFLAGS) -o fcmmio fcmmio.o -L. -lmmio $(LIBS)

fmmio: fmmio.o libmmiof.a
	$(FC) $(LFLAGS) -o fmmio fmmio.o -L. -lmmiof $(LIBS)

cfmmio.o: cfmmio.c mmio.h mmio_def.h
	$(CC) $(CFLAGS) cfmmio.c

cmmio.o: cmmio.c mmio.h mmio_def.h
	$(CC) $(CFLAGS) cmmio.c
	
libmmio.a: $(MMIO_OBJ)
	ar $(ARFLAGS) libmmio.a $(MMIO_OBJ)

libmmioc.a: $(MMIOC_OBJ)
	ar $(ARFLAGS) libmmioc.a $(MMIOC_OBJ)

libmmiof.a: $(MMIOF_OBJ)
	ar $(ARFLAGS) libmmiof.a $(MMIOF_OBJ)

mmio.o: mmio.h mmio_def.h mmioc.h mmio.c
	$(CC) $(CFLAGS) mmio.c

mmio-C.o: mmio.h mmio_def.h mmioc.h mmio.c
	$(CC) $(CFLAGS) -DC_API mmio.c
	mv mmio.o mmio-C.o

mmioc.o: mmio.h mmio_def.h mmioc.h mmioc.c
	$(CC) $(CFLAGS) mmioc.c

mmiof-CF.o: mmioc.h mmio_def.h mmiof.c
	$(CC) $(CFLAGS) -DCOMBINED_API mmiof.c
	mv mmiof.o mmiof-CF.o

mmiof-F.o: mmioc.h mmio_def.h mmiof.c
	$(CC) $(CFLAGS) mmiof.c
	mv mmiof.o mmiof-F.o

foutc.o: foutc.c
	$(CC) $(CFLAGS) foutc.c

fout.o: fout.f
	$(FC) $(FFLAGS) fout.f

fcmmio.o: fcmmio.f mmio.inc
	$(FC) $(FFLAGS) fcmmio.f

fmmio.o: fmmio.f mmio.inc
	$(FC) $(FFLAGS) fmmio.f

mmio_convert.o: mmio_convert.c mmio.h libmmio.a
	$(CC) $(CFLAGS) mmio_convert.c

mmio_uncompress.o: mmio_uncompress.f mmio.inc libmmiof.a
	$(FC) $(FFLAGS) mmio_uncompress.f

cmmio.c: $(MMIO_SRC_DIR)/cmmio.c
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . cmmio.c 
cfmmio.c: $(MMIO_SRC_DIR)/cfmmio.c
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . cfmmio.c 
fmmio.f: $(MMIO_SRC_DIR)/fmmio.f
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . fmmio.f 
fcmmio.f: $(MMIO_SRC_DIR)/fcmmio.f
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . fcmmio.f 
fout.f: $(MMIO_SRC_DIR)/fout.f
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . fout.f 
foutc.c: $(MMIO_SRC_DIR)/foutc.c
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . foutc.c 
mmio.c: $(MMIO_SRC_DIR)/mmio.c
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmio.c 
mmio.h: $(MMIO_SRC_DIR)/mmio.h
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmio.h 
mmio.inc: $(MMIO_SRC_DIR)/mmio.inc
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmio.inc 
mmio_convert.c: $(MMIO_SRC_DIR)/mmio_convert.c
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmio_convert.c 
mmio_def.h: $(MMIO_SRC_DIR)/mmio_def.h
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmio_def.h 
mmio_uncompress.f: $(MMIO_SRC_DIR)/mmio_uncompress.f
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmio_uncompress.f 
mmioc.c: $(MMIO_SRC_DIR)/mmioc.c
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmioc.c 
mmioc.h: $(MMIO_SRC_DIR)/mmioc.h
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmioc.h 
mmiof.c: $(MMIO_SRC_DIR)/mmiof.c
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . mmiof.c 
title.Fortran: $(MMIO_SRC_DIR)/title.Fortran
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . title.Fortran 
description.all: $(MMIO_SRC_DIR)/description.all
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . description.all 
description.Fortran: $(MMIO_SRC_DIR)/description.Fortran
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . description.Fortran 
title.C: $(MMIO_SRC_DIR)/title.C
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . title.C 
description.C: $(MMIO_SRC_DIR)/description.C
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . description.C 
ftest: $(MMIO_SRC_DIR)/ftest
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . ftest 
ctest: $(MMIO_SRC_DIR)/ctest
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . ctest 
fctest: $(MMIO_SRC_DIR)/fctest
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . fctest 
cftest: $(MMIO_SRC_DIR)/cftest
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . cftest 
gagfull.dat: $(MMIO_SRC_DIR)/gagfull.dat
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . gagfull.dat 
gagcomp.dat: $(MMIO_SRC_DIR)/gagcomp.dat
	$(BUILD_TOOLS)/my_cp $(MMIO_SRC_DIR) . gagcomp.dat 
